@@ -22,9 +22,9 @@ const Clutter = imports.gi.Clutter;
 const GdkPixbuf = imports.gi.GdkPixbuf;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
+const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
 const GtkClutter = imports.gi.GtkClutter;
-const Lang = imports.lang;
 const System = imports.system;
 
 const Service = imports.service;
@@ -38,36 +38,30 @@ const _MEMORY_CACHE_SIZE_LIMIT = 100; /* number of tiles */
 const _LOGO_PADDING_X = 10;
 const _LOGO_PADDING_Y = 25;
 
-var AttributionLogo = new Lang.Class({
-    Name: 'AttributionLogo',
-        Extends: GtkClutter.Actor,
+var AttributionLogo = GObject.registerClass({},
+class AttributionLogo extends GtkClutter.Actor {
 
-    _init: function(view) {
-        this.parent();
+    _init(view) {
+        super._init();
 
         if (_attributionImage)
             this.contents = _attributionImage;
         else
             return;
 
-        view.connect('notify::width', (function() {
-            this._updatePosition(view);
-        }).bind(this));
-
-        view.connect('notify::height', (function() {
-            this._updatePosition(view);
-        }).bind(this));
+        view.connect('notify::width', () => this._updatePosition(view));
+        view.connect('notify::height', () => this._updatePosition(view));
 
         this._updatePosition(view);
-    },
+    }
 
-    _updatePosition: function(view) {
+    _updatePosition(view) {
         let width = _attributionImage.pixbuf.width;
         let height = _attributionImage.pixbuf.height;
 
         this.set_position(view.width  - width  - _LOGO_PADDING_X,
                           view.height - height - _LOGO_PADDING_Y);
-    },
+    }
 });
 
 function _updateAttributionImage(source) {
